# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.162
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from nuon.models.app_role import AppRole

class TestAppRole(unittest.TestCase):
    """AppRole unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppRole:
        """Test AppRole
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppRole`
        """
        model = AppRole()
        if include_optional:
            return AppRole(
                created_by = nuon.models.app/account.app.Account(
                    account_type = 'auth0', 
                    created_at = '', 
                    email = '', 
                    id = '', 
                    org_ids = [
                        ''
                        ], 
                    orgs = [
                        nuon.models.app/org.app.Org(
                            created_at = '', 
                            created_by = nuon.models.app/account.app.Account(
                                created_at = '', 
                                email = '', 
                                id = '', 
                                permissions = {
                                    'key' : 'unknown'
                                    }, 
                                roles = [
                                    nuon.models.app/role.app.Role(
                                        created_at = '', 
                                        created_by_id = '', 
                                        id = '', 
                                        policies = [
                                            nuon.models.app/policy.app.Policy(
                                                created_at = '', 
                                                created_by_id = '', 
                                                id = '', 
                                                name = 'org_admin', 
                                                permissions = {
                                                    'key' : ''
                                                    }, 
                                                role_id = '', 
                                                updated_at = '', )
                                            ], 
                                        role_type = 'org_admin', 
                                        updated_at = '', )
                                    ], 
                                subject = '', 
                                updated_at = '', ), 
                            created_by_id = '', 
                            custom_cert = True, 
                            health_checks = [
                                nuon.models.app/org_health_check.app.OrgHealthCheck(
                                    created_at = '', 
                                    created_by_id = '', 
                                    id = '', 
                                    org_id = '', 
                                    status = 'ok', 
                                    status_description = '', 
                                    updated_at = '', )
                                ], 
                            id = '', 
                            latest_health_check = null, 
                            name = '', 
                            notifications_config = nuon.models.app/notifications_config.app.NotificationsConfig(
                                created_at = '', 
                                created_by_id = '', 
                                id = '', 
                                org_id = '', 
                                owner_id = '', 
                                owner_type = '', 
                                slack_webhook_url = '', 
                                updated_at = '', ), 
                            sandbox_mode = True, 
                            status = '', 
                            status_description = '', 
                            updated_at = '', 
                            vcs_connections = [
                                nuon.models.app/vcs_connection.app.VCSConnection(
                                    created_at = '', 
                                    created_by_id = '', 
                                    github_install_id = '', 
                                    id = '', 
                                    updated_at = '', 
                                    vcs_connection_commit = [
                                        nuon.models.app/vcs_connection_commit.app.VCSConnectionCommit(
                                            author_email = '', 
                                            author_name = '', 
                                            component_config_connection_id = '', 
                                            created_at = '', 
                                            created_by_id = '', 
                                            id = '', 
                                            message = '', 
                                            sha = '', 
                                            updated_at = '', )
                                        ], )
                                ], )
                        ], 
                    permissions = {
                        'key' : 'unknown'
                        }, 
                    roles = [
                        nuon.models.app/role.app.Role(
                            created_at = '', 
                            created_by_id = '', 
                            id = '', 
                            updated_at = '', )
                        ], 
                    subject = '', 
                    updated_at = '', ),
                created_at = '',
                created_by_id = '',
                id = '',
                policies = [
                    nuon.models.app/policy.app.Policy(
                        created_at = '', 
                        created_by = nuon.models.app/account.app.Account(
                            account_type = 'auth0', 
                            created_at = '', 
                            email = '', 
                            id = '', 
                            org_ids = [
                                ''
                                ], 
                            orgs = [
                                nuon.models.app/org.app.Org(
                                    created_at = '', 
                                    created_by_id = '', 
                                    custom_cert = True, 
                                    health_checks = [
                                        nuon.models.app/org_health_check.app.OrgHealthCheck(
                                            created_at = '', 
                                            created_by_id = '', 
                                            id = '', 
                                            org_id = '', 
                                            status = 'ok', 
                                            status_description = '', 
                                            updated_at = '', )
                                        ], 
                                    id = '', 
                                    latest_health_check = null, 
                                    name = '', 
                                    notifications_config = nuon.models.app/notifications_config.app.NotificationsConfig(
                                        created_at = '', 
                                        created_by_id = '', 
                                        id = '', 
                                        org_id = '', 
                                        owner_id = '', 
                                        owner_type = '', 
                                        slack_webhook_url = '', 
                                        updated_at = '', ), 
                                    sandbox_mode = True, 
                                    status = '', 
                                    status_description = '', 
                                    updated_at = '', 
                                    vcs_connections = [
                                        nuon.models.app/vcs_connection.app.VCSConnection(
                                            created_at = '', 
                                            created_by_id = '', 
                                            github_install_id = '', 
                                            id = '', 
                                            updated_at = '', 
                                            vcs_connection_commit = [
                                                nuon.models.app/vcs_connection_commit.app.VCSConnectionCommit(
                                                    author_email = '', 
                                                    author_name = '', 
                                                    component_config_connection_id = '', 
                                                    created_at = '', 
                                                    created_by_id = '', 
                                                    id = '', 
                                                    message = '', 
                                                    sha = '', 
                                                    updated_at = '', )
                                                ], )
                                        ], )
                                ], 
                            permissions = {
                                'key' : 'unknown'
                                }, 
                            roles = [
                                nuon.models.app/role.app.Role(
                                    created_by = nuon.models.app/account.app.Account(
                                        created_at = '', 
                                        email = '', 
                                        id = '', 
                                        permissions = {
                                            'key' : 'unknown'
                                            }, 
                                        subject = '', 
                                        updated_at = '', ), 
                                    created_at = '', 
                                    created_by_id = '', 
                                    id = '', 
                                    role_type = 'org_admin', 
                                    updated_at = '', )
                                ], 
                            subject = '', 
                            updated_at = '', ), 
                        created_by_id = '', 
                        id = '', 
                        name = 'org_admin', 
                        permissions = {
                            'key' : ''
                            }, 
                        role_id = '', 
                        updated_at = '', )
                    ],
                role_type = 'org_admin',
                updated_at = ''
            )
        else:
            return AppRole(
        )
        """

    def testAppRole(self):
        """Test AppRole"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.132
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from nuon.models.service_create_installer_request import ServiceCreateInstallerRequest

class TestServiceCreateInstallerRequest(unittest.TestCase):
    """ServiceCreateInstallerRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServiceCreateInstallerRequest:
        """Test ServiceCreateInstallerRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServiceCreateInstallerRequest`
        """
        model = ServiceCreateInstallerRequest()
        if include_optional:
            return ServiceCreateInstallerRequest(
                app_ids = [
                    ''
                    ],
                metadata = nuon.models.service_create_installer_request_metadata.service_CreateInstallerRequest_metadata(
                    community_url = '', 
                    copyright_markdown = '', 
                    demo_url = '', 
                    description = '', 
                    documentation_url = '', 
                    favicon_url = '', 
                    footer_markdown = '', 
                    github_url = '', 
                    homepage_url = '', 
                    logo_url = '', 
                    post_install_markdown = '', ),
                name = ''
            )
        else:
            return ServiceCreateInstallerRequest(
                app_ids = [
                    ''
                    ],
                name = '',
        )
        """

    def testServiceCreateInstallerRequest(self):
        """Test ServiceCreateInstallerRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.87
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from nuon.models.service_create_install_request_azure_account import ServiceCreateInstallRequestAzureAccount

class TestServiceCreateInstallRequestAzureAccount(unittest.TestCase):
    """ServiceCreateInstallRequestAzureAccount unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServiceCreateInstallRequestAzureAccount:
        """Test ServiceCreateInstallRequestAzureAccount
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServiceCreateInstallRequestAzureAccount`
        """
        model = ServiceCreateInstallRequestAzureAccount()
        if include_optional:
            return ServiceCreateInstallRequestAzureAccount(
                location = '',
                service_principal_app_id = '',
                service_principal_password = '',
                subscription_id = '',
                subscription_tenant_id = ''
            )
        else:
            return ServiceCreateInstallRequestAzureAccount(
        )
        """

    def testServiceCreateInstallRequestAzureAccount(self):
        """Test ServiceCreateInstallRequestAzureAccount"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
